@@ -1181,21 +1181,21 @@ class ePub(ElementProxy):
         uid = self.get("unique-identifier")
         text = lambda: f"urn:uuid:{uuid4()}"
         if uid:
-            return self.metadata.setdefault(f'dc:identifier[@id="{uid}"]', text=text, attrib={"id": uid})
+            return self.metadata.dc("identifier", find_attrib={"id": uid}, text=text, merge=True)
         else:
-            return self.metadata.setdefault("dc:identifier", text=text)
+            return self.metadata.dc("identifier", text=text, merge=True)
 
     @cache_meta_property
     def language(self):
-        return self.metadata.setdefault("dc:language", text="en")
+        return self.metadata.dc("language", text="en", merge=True)
 
     @cache_meta_property
     def title(self):
-        return self.metadata.setdefault("dc:title", text="")
+        return self.metadata.dc("title", text="", merge=True)
 
     @cache_meta_property(meta_attr="content", validator=lambda self, cover_id: cover_id in self)
     def cover(self, /) -> Optional[str]:
-        return self.metadata.setdefault('{*}meta[@name="cover"]', attrib={"name": "cover"})
+        return self.metadata.name_meta("cover")
 
     def pack(
         self, 
